@@ -24,9 +24,13 @@ from unittest import TestCase
 from unittest.mock import patch
 
 import logassert
+import pytest
 
 import ops.lib
 
+# Ignore deprecation warnings for this module.
+pytestmark = pytest.mark.filterwarnings('ignore::DeprecationWarning')
+
 
 def _mklib(topdir: str, pkgname: str, libname: str) -> Path:
     """Make a for-testing library.
@@ -466,8 +470,7 @@ class TestLibFunctional(TestCase):
                     # everything-is-the-same :-)
                     continue
                 for patch_a in [38, 42]:
-                    desc = "A: {}/{}/{}; B: {}/{}/{}".format(
-                        pkg_a, lib_a, patch_a, pkg_b, lib_b, patch_b)
+                    desc = f"A: {pkg_a}/{lib_a}/{patch_a}; B: {pkg_b}/{lib_b}/{patch_b}"
                     with self.subTest(desc):
                         tmpdir = self._mkdtemp()
                         sys.path = [tmpdir]
@@ -504,8 +507,7 @@ class TestLibFunctional(TestCase):
         for pkg_a in ["foo", "fooA"]:
             for lib_a in ["bar", "barA"]:
                 for patch_a in [38, 42]:
-                    desc = "A: {}/{}/{}; B: {}/{}/{}".format(
-                        pkg_a, lib_a, patch_a, pkg_b, lib_b, patch_b)
+                    desc = f"A: {pkg_a}/{lib_a}/{patch_a}; B: {pkg_b}/{lib_b}/{patch_b}"
                     with self.subTest(desc):
                         tmp_dir_a = self._mkdtemp()
                         tmp_dir_b = self._mkdtemp()
@@ -611,3 +613,14 @@ class TestLibFunctional(TestCase):
 
         with self.assertRaises(ImportError):
             ops.lib.use('baz', 2, 'bob@example.com')
+
+
+class TestDeprecationWarning(TestCase):
+    def test_autoimport_deprecated(self):
+        with self.assertWarns(DeprecationWarning):
+            ops.lib.autoimport()
+
+    def test_use_deprecated(self):
+        with self.assertWarns(DeprecationWarning):
+            with self.assertRaises(ImportError):
+                ops.lib.use('foo', 1, 'bob@example.com')
